//+------------------------------------------------------------------+
//|                                                    OpenOrder.mq4 |
//|                                                        Scriptong |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Scriptong"
#property link      ""
#property show_inputs

extern int     TakeProfit = 200;
extern int     StopLoss = 200;
extern double  Lots = 0;
extern double  DepoPercent = 10;
extern int     Slippage = 10;
extern int     TypeOrder = 1;  //   0 - Buy, 1 - Sell, 3 - SellLimit  . .
extern int     Offset = 100;   //        
extern int     MagicNumber = 42367;

//+------------------------------------------------------------------+
//|  /                                          |
//+------------------------------------------------------------------+
void OpenOrder(string sym, int cmd, double Vol, double Price, int Slip, double SL, double TP, string Com, int Mag, datetime exp, color arr)
{
 int check = MathMod(cmd, 2);
 if(!IsTradeContextBusy() && AccountFreeMarginCheck(sym, check, Vol) > 0) 
  {
   Comment(".   ...");
   int ticket = OrderSend(sym, cmd, Vol, Price, Slip, SL, TP, Com, Mag, exp, arr);
   Comment("");
   if(ticket < 0)
    {
      switch(cmd)
       {
         case OP_BUY: string S = "Buy"; break;
         case OP_SELL: S = "Sell"; break;
         case OP_SELLSTOP: S = "SellStop"; break;
         case OP_SELLLIMIT: S = "SellLimit"; break;
         case OP_BUYSTOP: S = "BuyStop"; break;
         case OP_BUYLIMIT: S = "BuyLimit"; break;
         default: S = " ";
        }
      Print("    ", S,".  N", GetLastError(), ", Price=", Price,", TP=", TP, ", SL=", SL, ", Bid=", Bid, ", Lots=", Vol);
     }
   }
 }  
 
double LotsCalculate(int Type)
{
 double Result;
 
 double MinLot = MarketInfo(Symbol(), MODE_MINLOT);
 double MaxLot = MarketInfo(Symbol(), MODE_MAXLOT);
 int MinDigits = NormalizeDouble(-MathLog(MinLot)/MathLog(10), 0);
 Type = MathMod(Type, 2);
 if(Lots == 0)
   Result = NormalizeDouble(DepoPercent/10*AccountBalance()/((AccountFreeMargin()-AccountFreeMarginCheck(Symbol(), Type, 10))), MinDigits);
  else
   Result = Lots; 
 if(Result < MinLot)
   Result = MinLot;
 if(Result > MaxLot)
   Result = MaxLot;    
 return(Result);
 } 
 

//+------------------------------------------------------------------+
//| script program start function                                    |
//+------------------------------------------------------------------+
int start()
  {
//----

 // *********************      *********************
    int Spread = MarketInfo(Symbol(), MODE_SPREAD);
    int StopLevel = MarketInfo(Symbol(), MODE_STOPLEVEL);
    
    //    
    if(Offset < StopLevel+1 && TypeOrder > 1)
      {
        Print("    Offset.  !");
        return(0);
       } 
      
    if(StopLoss <= StopLevel+Spread || TakeProfit <= StopLevel-Spread)
      {
        Print("   StopLoss  TakeProfit.  !");
        return(0);
       }
    
    if(Lots == 0 && (DepoPercent < 0 || DepoPercent > 100))
       {
         Print("    DepoPercent.  !");
         return(0);
        }
    
    
    if((Lots < MarketInfo(Symbol(), MODE_MINLOT) || Lots > MarketInfo(Symbol(), MODE_MAXLOT) 
      || NormalizeDouble(MathMod(Lots, MarketInfo(Symbol(), MODE_LOTSTEP)), 10) != 0) &&
       Lots != 0)
       {
         Print("    Lots.  !");
         return(0);
        }
        
    if(TypeOrder < 0 || TypeOrder > 5)
      {
        Print("   .  !");
        return(0);
       }

    if(!IsTradeAllowed())
      {
        Print("   .  !");
        return(0);
       }

         
 // ******************************************
      
 // *******************    ,    **************************
    switch(TypeOrder)
      {
        case 0: 
          double Price = Ask; 
          double SL = Ask - StopLoss*Point;
          double TP = Ask + TakeProfit*Point;
          break;
        case 1: 
          Price = Bid; 
          SL = Bid + StopLoss*Point;
          TP = Bid - TakeProfit*Point;
          break;
        case 2: 
          Price = Ask-Offset*Point; 
          SL = Price - StopLoss*Point;
          TP = Price + TakeProfit*Point;
          break;
        case 3: 
          Price = Bid+Offset*Point; 
          SL = Price + StopLoss*Point;
          TP = Price - TakeProfit*Point;
          break;
        case 4: 
          Price = Ask+Offset*Point; 
          SL = Price - StopLoss*Point;
          TP = Price + TakeProfit*Point;
          break;
        case 5: 
          Price = Bid-Offset*Point; 
          SL = Price + StopLoss*Point;
          TP = Price - TakeProfit*Point;
          break;
       } 
    // *************************************************************************************
    
    // ***************   ***************************   
    OpenOrder(Symbol(), TypeOrder, LotsCalculate(TypeOrder), Price, Slippage, SL, TP, NULL, MagicNumber, 0, CLR_NONE);   
//----
   return(0);
  }
//+------------------------------------------------------------------+